==> moodle-1.8.tgz: moodle/lang/en_utf8/data.php <==
<?PHP // $Id: data.php,v 1.50.2.1 2007/02/23 03:54:49 toyomoyo Exp $ 
      // data.php - created with Moodle 1.7 beta + (2006101003)


$string['action'] = 'Action';
$string['add'] = 'Add entry';
$string['addafield'] = 'Add a field';
$string['addcomment'] = 'Add comment';
$string['addentries'] = 'Add entries';
$string['addtemplate'] = 'Add template';
$string['allowcomments'] = 'Allow comments?';
$string['allowratings'] = 'Allow posts to be rated?';
$string['alttext'] = 'Alternative text';
$string['approve'] = 'Approve';
$string['ascending'] = 'Ascending';
$string['atmaxentry'] = 'You have entered the maximum number of entries allowed!';
$string['autogenallforms'] = 'Generate all default templates';
$string['autolinkurl'] = 'Autolink the URL';
$string['availablefromdate'] = 'Available from';
$string['availabletags'] = 'Available tags';
$string['availabletodate'] = 'Available to';
$string['blank'] = 'Blank';
$string['buttons'] = 'Buttons';
$string['bynameondate'] = 'by $a->name - $a->date';
$string['cancel'] = 'Cancel';
$string['checkbox'] = 'Checkbox';
$string['chooseorupload'] = 'Choose file';
$string['columns'] = 'columns';
$string['commentdeleted'] = 'Comment deleted';
$string['commentempty'] = 'Comment was empty';
$string['comment'] = 'Comment';
$string['comments'] = 'Comments';
$string['commentsaved'] = 'Comment saved';
$string['commentsn'] = '$a comment(s)';
$string['configenablerssfeeds'] = 'This switch will enable the possibility of RSS feeds for all databases. You will still need to turn feeds on manually in the settings for each database.';
$string['confirmdeletefield'] = 'You are about to delete this field, are you sure?';
$string['confirmdeleterecord'] = 'Are you sure you want to delete this entry?';
$string['csstemplate'] = 'CSS template';
$string['csvfile'] = 'CSV file';
$string['csvimport'] = 'CSV file import';
$string['data:approve'] = 'Approve unapproved entries';
$string['data:comment'] = 'Write comments';
$string['data:managecomments'] = 'Manage comments';
$string['data:manageentries'] = 'Manage entries';
$string['data:managetemplates'] = 'Manage templates';
$string['data:manageuserpresets'] = 'Manage all template presets';
$string['data:rate'] = 'Rate entries';
$string['data:readentry'] = 'Read entries';
$string['data:viewalluserpresets'] = 'View presets from all users';
$string['data:viewentry'] = 'View entries';
$string['data:viewrating'] = 'View ratings';
$string['data:writeentry'] = 'Write entries';
$string['date'] = 'Date';
$string['dateentered'] = 'Date entered';
$string['defaultfielddelimiter'] = '(default is the comma character)';
$string['defaultfieldenclosure'] = '(default is none)';
$string['defaultsortfield'] = 'Default sort field';
$string['delete'] = 'Delete';
$string['deletecomment'] = 'Are you sure you want to delete this comment?';
$string['deleted'] = 'deleted';
$string['deletefield'] = 'Delete an existing field';
$string['deletewarning'] = 'Are you sure you want to delete this preset?';
$string['descending'] = 'Descending';
$string['download'] = 'Download';
$string['edit'] = 'Edit';
$string['editcomment'] = 'Edit comment';
$string['editentry'] = 'Edit entry';
$string['editorenable'] = 'Enable editor';
$string['editordisable'] = 'Disable editor';
$string['emptyadd'] = 'The Add template is empty, generating a default form...';
$string['emptyaddform'] = 'You did not fill out any fields!';
$string['entries'] = 'Entries';
$string['entry'] = 'Entry';
$string['entrysaved'] = 'Your entry has been saved';
$string['errormustbeteacher'] = 'You need to be a teacher to use this page!';
$string['example'] = 'Database module example';
$string['export'] = 'Export';
$string['exportaszip'] = 'Export as zip';
$string['exportedtozip'] = 'Exported to temporary zip...';
$string['fieldadded'] = 'Field added';
$string['fieldallowautolink'] = 'Allow autolink';
$string['fielddeleted'] = 'Field deleted';
$string['fielddelimiter'] = 'Field delimiter';
$string['fielddescription'] = 'Field description';
$string['fieldenclosure'] = 'Field enclosure';
$string['fieldheight'] = 'Height';
$string['fieldheightlistview'] = 'Height in list view';
$string['fieldheightsingleview'] = 'Height in single view';
$string['fieldmappings'] = 'Field Mappings';
$string['fieldname'] = 'Field name';
$string['fieldoptions'] = 'Options (one per line)';
$string['fields'] = 'Fields';
$string['fieldids'] = 'Field ids';
$string['fieldupdated'] = 'Field updated';
$string['fieldwidth'] = 'Width';
$string['fieldwidthlistview'] = 'Width in list view';
$string['fieldwidthsingleview'] = 'Width in single view';
$string['file'] = 'File';
$string['filtername'] = 'Database Auto-linking';
$string['footer'] = 'Footer';
$string['forcelinkname'] = 'Forced name for the link';
$string['fromfile'] = 'Import from zip file';
$string['header'] = 'Header';
$string['headeraddtemplate'] = 'Defines the interface when editing entries';
$string['headercsstemplate'] = 'Defines local CSS styles for the other templates';
$string['headerjstemplate'] = 'Defines custom Javascript for the other templates';
$string['headerlisttemplate'] = 'Defines browsing interface for multiple entries';
$string['headerrsstemplate'] = 'Defines appearance of entries in RSS feeds';
$string['headersingletemplate'] = 'Defines browsing interface for a single entry';
$string['importsuccess'] = 'The preset has been successfully applied.';
$string['insufficiententries'] = 'more entries needed to view this database';
$string['intro'] = 'Introduction';
$string['invalidfieldname'] = 'Please choose another name for this field';
$string['invalidurl'] = 'The URL you just entered is not valid';
$string['jstemplate'] = 'Javascript template';
$string['latitude'] = 'Latitude';
$string['latlong'] = 'Latitude/longitude';
$string['latlongdownloadallhint'] = 'Download link for all entries as KML';
$string['latlongkmllabelling'] = 'How to label items in KML files (Google Earth)';
$string['latlonglinkservicesdisplayed'] = 'Link-out services to display';
$string['latlongotherfields'] = 'Other fields';
$string['list'] = 'View list';
$string['listtemplate'] = 'List template';
$string['longitude'] = 'Longitude';
$string['mappingwarning'] = 'All old fields not mapped to a new field will be lost and all data in that field will be removed.';
$string['maxentries'] = 'Maximum entries';
$string['maxsize'] = 'Maximum size';
$string['menu'] = 'Menu';
$string['menuchoose'] = 'Choose...';
$string['modulename'] = 'Database';
$string['modulenameplural'] = 'Databases';
$string['more'] = 'More';
$string['moreurl'] = 'More URL';
$string['multientry'] = 'Repeated entry';
$string['multimenu'] = 'Menu (Multi-select)';
$string['multipletags'] = 'Multiple tags found! Template not saved';
$string['namecheckbox'] = 'Checkbox field';
$string['namedate'] = 'Date field';
$string['namefile'] = 'File field';
$string['namelatlong'] = 'Latitude/longitude field';
$string['namemenu'] = 'Menu field';
$string['namemultimenu'] = 'Multiple-selection menu field';
$string['namenumber'] = 'Number field';
$string['namepicture'] = 'Picture field';
$string['nameradiobutton'] = 'Radio button field';
$string['nametext'] = 'Text field';
$string['nametextarea'] = 'Textarea field';
$string['nameurl'] = 'URL field';
$string['newentry'] = 'New entry';
$string['newfield'] = 'Create a new field';
$string['noaccess'] = 'You do not have access to this page';
$string['nofieldindatabase'] = 'There are no fields defined for this database.';
$string['nolisttemplate'] = 'List template is not yet defined';
$string['nomatch'] = 'No matching entries found!';
$string['nomaximum'] = 'No maximum';
$string['norecords'] = 'No entries in database';
$string['nosingletemplate'] = 'Single template is not yet defined';
$string['number'] = 'Number';
$string['numberrssarticles'] = 'RSS articles';
$string['numnotapproved'] = 'Pending';
$string['numrecords'] = '$a entries';
$string['optionaldescription'] = 'Short description (optional)';
$string['optionalfilename'] = 'Filename (optional)';
$string['overwrite'] = 'Overwrite';
$string['pagesize'] = 'Entries per page';
$string['participants'] = 'Participants';
$string['picture'] = 'Picture';
$string['pleaseaddsome'] = 'Please create some below or <a href=\"$a\">choose a predefined set</a> to get started.';
$string['presetinfo'] = 'Saving as a preset will publish this template. Other users may be able to use it in their databases.';
$string['presets'] = 'Presets';
$string['radiobutton'] = 'Radio buttons';
$string['rate'] = 'Rate';
$string['rating'] = 'Rating';
$string['ratingeveryone'] = 'Everyone can rate posts';
$string['ratingno'] = 'No ratings';
$string['ratingonlyteachers'] = 'Only $a can rate posts';
$string['ratingpublic'] = '$a can see everyone\'s ratings';
$string['ratingpublicnot'] = '$a can only see their own ratings';
$string['ratings'] = 'Ratings';
$string['ratingssaved'] = 'Ratings saved';
$string['ratingsuse'] = 'Use ratings';
$string['recordapproved'] = 'Entry approved';
$string['recorddeleted'] = 'Entry deleted';
$string['recordsnotsaved'] = 'No entry was saved. Please check the format of the uploaded file.';
$string['recordssaved'] = 'entries saved';
$string['requireapproval'] = 'Require approval?';
$string['requiredentries'] = 'Required entries';
$string['requiredentriestoview'] = 'Entries required before viewing';
$string['resettemplate'] = 'Reset template';
$string['resizingimages'] = 'Resizing image thumbnails...';
$string['rows'] = 'rows';
$string['rssglobaldisabled'] = 'Disabled. See site configuration variables.';
$string['rsshowmany'] = '(number of latest entries to show, 0 to disable RSS)';
$string['rsstemplate'] = 'RSS template';
$string['rsstitletemplate'] = 'RSS title template';
$string['save'] = 'Save';
$string['saveandadd'] = 'Save and add another';
$string['saveandview'] = 'Save and view';
$string['saveaspreset'] = 'Save as preset';
$string['savesettings'] = 'Save settings';
$string['savesuccess'] = 'Saved successfully. Your preset will now be available across the site.';
$string['savetemplate'] = 'Save template';
$string['sendinratings'] = 'Send in my latest ratings';
$string['single'] = 'View single';
$string['singletemplate'] = 'Single template';
$string['showall'] = 'Show all entries';
$string['teachersandstudents'] = '$a->teachers and $a->students';
$string['templates'] = 'Templates';
$string['templatesaved'] = 'Template saved';
$string['text'] = 'Text';
$string['textarea'] = 'Textarea';
$string['todatabase'] = 'to this database.';
$string['type'] = 'Field type';
$string['updatefield'] = 'Update an existing field';
$string['uploadfile'] = 'Upload file';
$string['uploadrecords'] = 'Upload entries from a file';
$string['url'] = 'Url';
$string['usestandard'] = 'Use a preset';
$string['viewfromdate'] = 'Viewable from';
$string['viewtodate'] = 'Viewable to';

?>

==> moodle-1.9.1.tgz: moodle/lang/en_utf8/data.php <==
<?PHP // $Id: data.php,v 1.53.4.13 2008/04/20 10:08:04 skodak Exp $ 
      // data.php - created with Moodle 1.7 beta + (2006101003)


$string['action'] = 'Action';
$string['add'] = 'Add entry';
$string['addafield'] = 'Add a field';
$string['addcomment'] = 'Add comment';
$string['addentries'] = 'Add entries';
$string['addtemplate'] = 'Add template';
$string['advancedsearch'] = 'Advanced search';
$string['allowcomments'] = 'Allow comments?';
$string['allowratings'] = 'Allow posts to be rated?';
$string['alttext'] = 'Alternative text';
$string['approve'] = 'Approve';
$string['approved'] = 'Approved';
$string['ascending'] = 'Ascending';
$string['asearchtemplate'] = 'Advanced search template';
$string['atmaxentry'] = 'You have entered the maximum number of entries allowed!';
$string['authorfirstname'] = 'Author first name';
$string['authorlastname'] = 'Author surname';
$string['autogenallforms'] = 'Generate all default templates';
$string['autolinkurl'] = 'Autolink the URL';
$string['availablefromdate'] = 'Available from';
$string['availabletags'] = 'Available tags';
$string['availabletodate'] = 'Available to';
$string['blank'] = 'Blank';
$string['buttons'] = 'Actions';
$string['bynameondate'] = 'by $a->name - $a->date';
$string['cancel'] = 'Cancel';
$string['checkbox'] = 'Checkbox';
$string['chooseorupload'] = 'Choose file';
$string['columns'] = 'columns';
$string['commentdeleted'] = 'Comment deleted';
$string['commentempty'] = 'Comment was empty';
$string['comment'] = 'Comment';
$string['comments'] = 'Comments';
$string['commentsaved'] = 'Comment saved';
$string['commentsn'] = '$a comment(s)';
$string['configenablerssfeeds'] = 'This switch will enable the possibility of RSS feeds for all databases. You will still need to turn feeds on manually in the settings for each database.';
$string['confirmdeletefield'] = 'You are about to delete this field, are you sure?';
$string['confirmdeleterecord'] = 'Are you sure you want to delete this entry?';
$string['csstemplate'] = 'CSS template';
$string['csvfile'] = 'CSV file';
$string['csvimport'] = 'CSV file import';
$string['data:approve'] = 'Approve unapproved entries';
$string['data:comment'] = 'Write comments';
$string['data:managecomments'] = 'Manage comments';
$string['data:manageentries'] = 'Manage entries';
$string['data:managetemplates'] = 'Manage templates';
$string['data:manageuserpresets'] = 'Manage all template presets';
$string['data:rate'] = 'Rate entries';
$string['data:readentry'] = 'Read entries';
$string['data:viewalluserpresets'] = 'View presets from all users';
$string['data:viewentry'] = 'View entries';
$string['data:viewrating'] = 'View ratings';
$string['data:writeentry'] = 'Write entries';
$string['date'] = 'Date';
$string['dateentered'] = 'Date entered';
$string['defaultfielddelimiter'] = '(default is the comma character)';
$string['defaultfieldenclosure'] = '(default is none)';
$string['defaultsortfield'] = 'Default sort field';
$string['delete'] = 'Delete';
$string['deleteallentries'] = 'Delete all entries';
$string['deletecomment'] = 'Are you sure you want to delete this comment?';
$string['deletenotenrolled'] = 'Delete entries by users not enrolled';
$string['deleted'] = 'deleted';
$string['deletefield'] = 'Delete an existing field';
$string['deletewarning'] = 'Are you sure you want to delete this preset?';
$string['descending'] = 'Descending';
$string['directorynotapreset'] = '$a->directory Not a preset: missing files: $a->missing_files';
$string['download'] = 'Download';
$string['edit'] = 'Edit';
$string['editcomment'] = 'Edit comment';
$string['editentry'] = 'Edit entry';
$string['editorenable'] = 'Enable editor';
$string['editordisable'] = 'Disable editor';
$string['emptyadd'] = 'The Add template is empty, generating a default form...';
$string['emptyaddform'] = 'You did not fill out any fields!';
$string['entries'] = 'Entries';
$string['entrieslefttoadd'] = 'You must add $a->entriesleft more entry/entries before you can view other participants\' entries.';
$string['entry'] = 'Entry';
$string['entrysaved'] = 'Your entry has been saved';
$string['errormustbeteacher'] = 'You need to be a teacher to use this page!';
$string['example'] = 'Database module example';
$string['export'] = 'Export';
$string['exportaszip'] = 'Export as zip';
$string['exportedtozip'] = 'Exported to temporary zip...';
$string['failedpresetdelete'] = 'Error deleting a preset!';
$string['fieldadded'] = 'Field added';
$string['fieldallowautolink'] = 'Allow autolink';
$string['fielddeleted'] = 'Field deleted';
$string['fielddelimiter'] = 'Field delimiter';
$string['fielddescription'] = 'Field description';
$string['fieldenclosure'] = 'Field enclosure';
$string['fieldheight'] = 'Height';
$string['fieldheightlistview'] = 'Height in list view';
$string['fieldheightsingleview'] = 'Height in single view';
$string['fieldmappings'] = 'Field Mappings';
$string['fieldname'] = 'Field name';
$string['fieldoptions'] = 'Options (one per line)';
$string['fields'] = 'Fields';
$string['fieldids'] = 'Field ids';
$string['fieldupdated'] = 'Field updated';
$string['fieldwidth'] = 'Width';
$string['fieldwidthlistview'] = 'Width in list view';
$string['fieldwidthsingleview'] = 'Width in single view';
$string['file'] = 'File';
$string['filesnotgenerated'] = 'Not all files were generated: $a';
$string['filtername'] = 'Database Auto-linking';
$string['footer'] = 'Footer';
$string['forcelinkname'] = 'Forced name for the link';
$string['foundrecords'] = 'Found records: $a->num/$a->max (<a href=\"$a->reseturl\">Reset filters</a>)';
$string['foundnorecords'] = 'No records found (<a href=\"$a->reseturl\">Reset filters</a>)';
$string['fromfile'] = 'Import from zip file';
$string['header'] = 'Header';
$string['headeraddtemplate'] = 'Defines the interface when editing entries';
$string['headerasearchtemplate'] = 'Defines the interface for Advanced Searches';
$string['headercsstemplate'] = 'Defines local CSS styles for the other templates';
$string['headerjstemplate'] = 'Defines custom Javascript for the other templates';
$string['headerlisttemplate'] = 'Defines browsing interface for multiple entries';
$string['headerrsstemplate'] = 'Defines appearance of entries in RSS feeds';
$string['headersingletemplate'] = 'Defines browsing interface for a single entry';
$string['importsuccess'] = 'The preset has been successfully applied.';
$string['insufficiententries'] = 'more entries needed to view this database';
$string['intro'] = 'Introduction';
$string['invalidfieldname'] = 'Please choose another name for this field';
$string['invalidurl'] = 'The URL you just entered is not valid';
$string['jstemplate'] = 'Javascript template';
$string['latitude'] = 'Latitude';
$string['latlong'] = 'Latitude/longitude';
$string['latlongdownloadallhint'] = 'Download link for all entries as KML';
$string['latlongkmllabelling'] = 'How to label items in KML files (Google Earth)';
$string['latlonglinkservicesdisplayed'] = 'Link-out services to display';
$string['latlongotherfields'] = 'Other fields';
$string['list'] = 'View list';
$string['listtemplate'] = 'List template';
$string['longitude'] = 'Longitude';
$string['mappingwarning'] = 'All old fields not mapped to a new field will be lost and all data in that field will be removed.';
$string['maxentries'] = 'Maximum entries';
$string['maxsize'] = 'Maximum size';
$string['menu'] = 'Menu';
$string['menuchoose'] = 'Choose...';
$string['modulename'] = 'Database';
$string['modulenameplural'] = 'Databases';
$string['more'] = 'More';
$string['moreurl'] = 'More URL';
$string['movezipfailed'] = 'Can\'t move zip';
$string['multientry'] = 'Repeated entry';
$string['multimenu'] = 'Menu (Multi-select)';
$string['multipletags'] = 'Multiple tags found! Template not saved';
$string['namecheckbox'] = 'Checkbox field';
$string['namedate'] = 'Date field';
$string['namefile'] = 'File field';
$string['namelatlong'] = 'Latitude/longitude field';
$string['namemenu'] = 'Menu field';
$string['namemultimenu'] = 'Multiple-selection menu field';
$string['namenumber'] = 'Number field';
$string['namepicture'] = 'Picture field';
$string['nameradiobutton'] = 'Radio button field';
$string['nametext'] = 'Text field';
$string['nametextarea'] = 'Textarea field';
$string['nameurl'] = 'URL field';
$string['newentry'] = 'New entry';
$string['newfield'] = 'Create a new field';
$string['noaccess'] = 'You do not have access to this page';
$string['nodefinedfields'] = 'New preset has no defined fields!';
$string['nofieldindatabase'] = 'There are no fields defined for this database.';
$string['nolisttemplate'] = 'List template is not yet defined';
$string['nomatch'] = 'No matching entries found!';
$string['nomaximum'] = 'No maximum';
$string['norecords'] = 'No entries in database';
$string['nosingletemplate'] = 'Single template is not yet defined';
$string['notinjectivemap'] = 'Not an injective map';
$string['number'] = 'Number';
$string['numberrssarticles'] = 'RSS articles';
$string['numnotapproved'] = 'Pending';
$string['numrecords'] = '$a entries';
$string['optionaldescription'] = 'Short description (optional)';
$string['optionalfilename'] = 'Filename (optional)';
$string['other'] = 'Other';
$string['overwrite'] = 'Overwrite';
$string['overwritesettings'] = 'Overwrite current settings';
$string['pagesize'] = 'Entries per page';
$string['participants'] = 'Participants';
$string['picture'] = 'Picture';
$string['pleaseaddsome'] = 'Please create some below or <a href=\"$a\">choose a predefined set</a> to get started.';
$string['presetinfo'] = 'Saving as a preset will publish this template. Other users may be able to use it in their databases.';
$string['presets'] = 'Presets';
$string['radiobutton'] = 'Radio buttons';
$string['rate'] = 'Rate';
$string['rating'] = 'Rating';
$string['ratingeveryone'] = 'Everyone can rate posts';
$string['ratingno'] = 'No ratings';
$string['ratingonlyteachers'] = 'Only $a can rate posts';
$string['ratingpublic'] = '$a can see everyone\'s ratings';
$string['ratingpublicnot'] = '$a can only see their own ratings';
$string['ratings'] = 'Ratings';
$string['ratingssaved'] = 'Ratings saved';
$string['ratingsuse'] = 'Use ratings';
$string['recordapproved'] = 'Entry approved';
$string['recorddeleted'] = 'Entry deleted';
$string['recordsnotsaved'] = 'No entry was saved. Please check the format of the uploaded file.';
$string['recordssaved'] = 'entries saved';
$string['requireapproval'] = 'Require approval?';
$string['requiredentries'] = 'Required entries';
$string['requiredentriestoview'] = 'Entries required before viewing';
$string['resettemplate'] = 'Reset template';
$string['resetsettings'] = 'Reset filters';
$string['resizingimages'] = 'Resizing image thumbnails...';
$string['rows'] = 'rows';
$string['rssglobaldisabled'] = 'Disabled. See site configuration variables.';
$string['rsshowmany'] = '(number of latest entries to show, 0 to disable RSS)';
$string['rsstemplate'] = 'RSS template';
$string['rsstitletemplate'] = 'RSS title template';
$string['save'] = 'Save';
$string['saveandadd'] = 'Save and add another';
$string['saveandview'] = 'Save and view';
$string['saveaspreset'] = 'Save as preset';
$string['savesettings'] = 'Save settings';
$string['savesuccess'] = 'Saved successfully. Your preset will now be available across the site.';
$string['savetemplate'] = 'Save template';
$string['search'] = 'Search';
$string['selectedrequired'] = 'All selected required';
$string['sendinratings'] = 'Send in my latest ratings';
$string['single'] = 'View single';
$string['singletemplate'] = 'Single template';
$string['showall'] = 'Show all entries';
$string['teachersandstudents'] = '$a->teachers and $a->students';
$string['templates'] = 'Templates';
$string['templatesaved'] = 'Template saved';
$string['text'] = 'Text';
$string['textarea'] = 'Textarea';
$string['timeadded'] = 'Time added';
$string['timemodified'] = 'Time modified';
$string['todatabase'] = 'to this database.';
$string['type'] = 'Field type';
$string['undefinedprocessactionmethod'] = 'No action method defined in Data_Preset to handle action \"$a\".';
$string['updatefield'] = 'Update an existing field';
$string['uploadfile'] = 'Upload file';
$string['uploadrecords'] = 'Upload entries from a file';
$string['url'] = 'Url';
$string['usestandard'] = 'Use a preset';
$string['viewfromdate'] = 'Viewable from';
$string['viewtodate'] = 'Viewable to';
$string['wrongdataid'] = 'Wrong data id provided';
?>
